pear
====

pear is a stupidly simple aur helper

commands
--------

``pear query string`` - query all packages using ``string`` as a search
keyword

``pear install package`` - download and install the package named
``package``

``pear upgrade`` - upgrade all installed aur packages

``pear list`` - list all installed aur packages
